<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class CategoriaEquipFactory {
    use TQuery;

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    public function getCategorias() {
        $sql = "SELECT DISTINCT FCM_CATEGORIAEQUIP.NRCATEGORIAEQUIP, FCM_CATEGORIAEQUIP.NMCATEGORIAEQUIP,
                      (SELECT LISTAGG(FCM_CATEGORIAMANUT.NMCATEGORIAMANUT, ', ') WITHIN GROUP (ORDER BY FCM_CATEGORIAMANUT.NMCATEGORIAMANUT)
                                               FROM FCM_CATEGORIAMANUT
                                               JOIN FCM_RELCATEGORIAEQUIPMANUT
                                                ON FCM_CATEGORIAMANUT.NRCATEGORIAMANUT = FCM_RELCATEGORIAEQUIPMANUT.NRCATEGORIAMANUT
                                               WHERE FCM_CATEGORIAEQUIP.NRCATEGORIAEQUIP = FCM_RELCATEGORIAEQUIPMANUT.NRCATEGORIAEQUIP) AS NMTIPOMANUTENCAO,
                      (SELECT LISTAGG(FCM_CATEGORIAMANUT.NRCATEGORIAMANUT, ',') WITHIN GROUP (ORDER BY FCM_CATEGORIAMANUT.NMCATEGORIAMANUT)
                                               FROM FCM_CATEGORIAMANUT
                                               JOIN FCM_RELCATEGORIAEQUIPMANUT
                                                ON FCM_CATEGORIAMANUT.NRCATEGORIAMANUT = FCM_RELCATEGORIAEQUIPMANUT.NRCATEGORIAMANUT
                                               WHERE FCM_CATEGORIAEQUIP.NRCATEGORIAEQUIP = FCM_RELCATEGORIAEQUIPMANUT.NRCATEGORIAEQUIP) AS NRTIPOMANUTENCAO,
                      (SELECT LISTAGG(FCM_EQUIPAMENTO.NMEQUIPAMENTO, ',') WITHIN GROUP (ORDER BY FCM_EQUIPAMENTO.NMEQUIPAMENTO)
                                               FROM FCM_EQUIPAMENTO
                                               WHERE FCM_CATEGORIAEQUIP.NRCATEGORIAEQUIP = FCM_EQUIPAMENTO.NRCATEGORIAEQUIP) AS NMEQUIPAMENTO,
                      (SELECT LISTAGG(FCM_EQUIPAMENTO.NREQUIPAMENTO, ',') WITHIN GROUP (ORDER BY FCM_EQUIPAMENTO.NMEQUIPAMENTO)
                                               FROM FCM_EQUIPAMENTO
                                               WHERE FCM_CATEGORIAEQUIP.NRCATEGORIAEQUIP = FCM_EQUIPAMENTO.NRCATEGORIAEQUIP) AS NREQUIPAMENTO
                FROM FCM_CATEGORIAEQUIP";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, [], [], null, null, null, ['NRTIPOMANUTENCAO']);
    }

    public function insertCategoria($parametros) {
        $sql = "INSERT INTO FCM_CATEGORIAEQUIP (
                    NRCATEGORIAEQUIP,   NMCATEGORIAEQUIP,   NRORG,          IDATIVO,
                    DTINCLUSAO,         CDOPERINCLUSAO,     NRORGINCLUSAO
                )
                VALUES (
                    :NRCATEGORIAEQUIP,  :NMCATEGORIAEQUIP,  :NRORG,         'S',
                    SYSDATE,            :CDOPERINCLUSAO,    :NRORGINCLUSAO
                )";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateCategoria($parametros) {
        $sql = "UPDATE FCM_CATEGORIAEQUIP
                SET NNMCATEGORIAEQUIP   = :NMCATEGORIAEQUIP,
                    DTULTATU            = SYSDATE
                    CDOPERULTATU        = :CDOPERULTATU,
                    NRORGULTATU         = :NRORGULTATU
                WHERE NRCATEGORIAEQUIP = :NRCATEGORIAEQUIP";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function insertRelCatManut($parametros) {
        $sql = "INSERT INTO FCM_RELCATEGORIAEQUIPMANUT (NRRELCATEGORIAEQUIPMANUT, NRCATEGORIAEQUIP, NRCATEGORIAMANUT, NRORG, IDATIVO, DTINCLUSAO)
                VALUES (:NRRELCATEGORIAEQUIPMANUT, :NRCATEGORIAEQUIP, :NRCATEGORIAMANUT, :NRORG, 'S', SYSDATE)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function deleteRelCatEquipManut($parametros) {
        $sql = "DELETE
                FROM FCM_RELCATEGORIAEQUIPMANUT
                WHERE NRCATEGORIAEQUIP IN (".$parametros.")";

        $this->connection->executeStatement($sql);
    }

    public function deleteCategorias($parametros) {
        $sql = "DELETE
                FROM FCM_CATEGORIAEQUIP
                WHERE NRCATEGORIAEQUIP IN (".$parametros.")";

        $this->connection->executeStatement($sql);
    }

    public function getCategManutencao() {
        $sql = "SELECT NRCATEGORIAMANUT, NMCATEGORIAMANUT
                FROM FCM_CATEGORIAMANUT";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getEquip() {
        $sql = "SELECT NREQUIPAMENTO, NMEQUIPAMENTO
                FROM FCM_EQUIPAMENTO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
}

?>