<?php

namespace FM\Service;

use FM\Factory\InsumoFactory;
use FM\Factory\ImgInsumoFactory;
use FM\Service\FileServerService;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class InsumoService {

    protected $InsumoFactory;
    protected $ImgInsumoFactory;
    protected $FileServerService;
    protected $Environment;
    protected $newCode;
    protected $connection;
    protected $fileServerApiKeys;
    protected $fileServerUrl;

    public function __construct (EntityManager $entityManager, FileServerService $FileServerService, InsumoFactory $InsumoFactory, Environment $Environment, NewCode $newCode,  $fileServerApiKeys, $fileServerUrl) {
        $this->InsumoFactory = $InsumoFactory;
        $this->FileServerService = $FileServerService;
        $this->Environment = $Environment;
        $this->connection = $entityManager->getConnection();
        $this->newCode = $newCode;
        $this->fileServerApiKeys = $fileServerApiKeys;
        $this->fileServerUrl = $fileServerUrl;
    }

    public function getInsumos() {
        return $this->InsumoFactory->getInsumos();
    }

    public function salvarInsumo($params) {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();
            if ($params["NRROW"] == null) {
                $NRINSUMO = $this->newCode->getCodeByTableName("FCM_INSUMO", 20, 1, 10, true);

                $parametroInsumo = array(
                    "NRINSUMO"          => $NRINSUMO,
                    "NMINSUMO"          => $params["NMINSUMO"],
                    "CDINSUMO"          => $params["CDINSUMO"],
                    "CDPRODUTO"         => $params["CDPRODUTO"],
                    "NRUNIDADEMEDIDA"   => $params["NRUNIDADEMEDIDA"],
                    "NRORG"             => $nrorg,
                    "CDOPERINCLUSAO"    => $operador,
                    "NRORGINCLUSAO"     => $nrorg
                );
                
                $this->InsumoFactory->insertInsumo($parametroInsumo);
            } else {
                $parametroInsumo = array(
                    "NRINSUMO"          => $params["NRROW"],
                    "NMINSUMO"          => $params["NMINSUMO"],
                    "CDINSUMO"          => $params["CDINSUMO"],
                    "CDPRODUTO"         => $params["CDPRODUTO"],
                    "NRUNIDADEMEDIDA"   => $params["NRUNIDADEMEDIDA"],
                    "CDOPERULTATU"      => $operador,
                    "NRORGULTATU"       => $nrorg
                );
    
                $this->InsumoFactory->updateInsumo($parametroInsumo);
            }

            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
        }
    }

    public function deleteInsumos($params) {
        $parametro = implode(',', $params["ROWS"]);
        $this->InsumoFactory->deleteInsumos($parametro);
    }

    public function insertFotosInsumo($params) {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrorg();

            foreach($params["FOTOS"] as $foto) {
                $img = $this->FileServerService->uploadFoto([$foto], "foto_manutencao_fmt");

                $NRIMGINSUMO = $this->newCode->getCodeByTableName('FCM_IMGINSUMO', 20, 1, 10, true);
                $parametroImagem = array(
                    "NRIMGINSUMO"   => $NRIMGINSUMO,
                    "NRINSUMO"      => $params["NRINSUMO"],
                    "DSCAMINHO"     => $this->fileServerUrl . "/files/" . $img["path"],
                    "NRORG"         => $nrorg,
                    "DSTYPE"        => $img["type"],
                    "NRSIZE"        => $img["size"]
                );
                
                $this->InsumoFactory->insertImgInsumo($parametroImagem);
            }

            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
        }
    }

    public function getFotosInsumo($params) {
        $parametroFotos = array(
            "NRINSUMO" => $params["NRINSUMO"]
        );

        return $this->InsumoFactory->getFotosInsumo($parametroFotos);
    }

    public function deleteFotoInsumo($params) {
        $parametroFoto = array(
            "NRIMGINSUMO" => $params["NRIMGINSUMO"]
        );

        return $this->InsumoFactory->deleteFotoInsumo($parametroFoto);
    }

    public function getUniMedida() {
        return $this->InsumoFactory->getUniMedida();
    }
}

?>