<?php

namespace FM\Service;

use FM\Factory\PrioridadeManutFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class PrioridadeManutService
{

    protected $PrioridadeManutFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(EntityManager $entityManager, PrioridadeManutFactory $PrioridadeManutFactory, Environment $Environment, NewCode $newCode)
    {
        $this->PrioridadeManutFactory = $PrioridadeManutFactory;
        $this->connection             = $entityManager->getConnection();
        $this->Environment            = $Environment;
        $this->newCode                = $newCode;
    }

    public function inserirPrioridade($parametros)
    {
        $NRORG = 20;
        $this->connection->beginTransaction();

        try {
            $NRPRIORIDADEMANUT = $this->newCode->getCodeByTableName("FCM_PRIORIDADEMANUT", $NRORG, 1, 10, true);

            $parametrosPrioridade = array(
                "NRPRIORIDADEMANUT" => $NRPRIORIDADEMANUT,
                "NMPRIORIDADEMANUT" => $parametros['NMPRIORIDADE'],
                "DSCORPRIORIDADE" => $parametros['CORPRIORIDADE']
            );

            $this->PrioridadeManutFactory->inserirPrioridade($parametrosPrioridade);

            foreach ($parametros['NRIMPACTOS'] as $Impacto) {
                $RELPRIORIDADEIMPACTO = $this->newCode->getCodeByTableName("FCM_RELPRIORIDADEIMPACTO", $NRORG, 1, 10, true);

                $parametrosImpacto = array(
                    "RELPRIORIDADEIMPACTO" => $RELPRIORIDADEIMPACTO,
                    "NRPRIORIDADEMANUT"    => $NRPRIORIDADEMANUT,
                    "NRIMPACTOMANUT"       => $Impacto,
                );
                $this->PrioridadeManutFactory->inserirImpactoRelacionado($parametrosImpacto);
            }


            $this->connection->commit();
            $response = 'OK';
        } catch (\Exception $e) {
            $this->connection->rollback();
            $response = ($e->getMessage());
        }
        return $response;
    }

    public function savePrioridade($params)
    {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();

            foreach ($params["ROWS"] as $row) {
                $impactosRelacionados = $row['NRIMPACTOMANUT'];

                if ($row["NRPRIORIDADEMANUT"] == 0) {
                    $NRPRIORIDADEMANUT = $this->newCode->getCodeByTableName("FCM_PRIORIDADEMANUT", $nrorg, 1, 10, true);
                    $corPrioridade = isset($row['DSCORPRIORIDADE']) ? $row['DSCORPRIORIDADE'] : "#000000";

                    $parametrosPrioridade = array(
                        "NRPRIORIDADEMANUT" => $NRPRIORIDADEMANUT,
                        "NMPRIORIDADEMANUT" => $row['NMPRIORIDADEMANUT'],
                        "DSCORPRIORIDADE"   => $corPrioridade,
                        "NRORG"             => $nrorg,
                        "CDOPERINCLUSAO"    => $operador,
                        "NRORGINCLUSAO"     => $nrorg,
                        "CDOPERULTATU"      => $operador,
                        "NRORGULTATU"       => $nrorg
                    );

                    $this->PrioridadeManutFactory->insertPrioridade($parametrosPrioridade);

                    foreach ($impactosRelacionados as $impacto) {
                        $this->insertImpactoRelacionado($row, $NRPRIORIDADEMANUT, $impacto, $nrorg, $operador);
                    }
                } else {
                    $parametrosPrioridade = array(
                        "NRPRIORIDADEMANUT" => $row["NRPRIORIDADEMANUT"],
                        "NMPRIORIDADEMANUT" => $row["NMPRIORIDADEMANUT"],
                        "DSCORPRIORIDADE"   => $row["DSCORPRIORIDADE"],
                        "CDOPERULTATU"      => $operador,
                        "NRORGULTATU"       => $nrorg
                    );

                    $this->PrioridadeManutFactory->editPrioridade($parametrosPrioridade);

                    foreach ($impactosRelacionados as $impacto) {
                        $parametrosRelacionamento = array(
                            "NRPRIORIDADEMANUT" => $row["NRPRIORIDADEMANUT"],
                            "NRIMPACTOMANUT"    => $impacto
                        );

                        $numRelacionamentos = $this->PrioridadeManutFactory->verificaRelPrioridadeImpacto($parametrosRelacionamento);

                        if ($numRelacionamentos == 0) {
                            $this->insertImpactoRelacionado($row, $row["NRPRIORIDADEMANUT"], $impacto, $nrorg, $operador);
                        }
                    }

                    $parametroImpactosDesatualizados = array(
                        "NRPRIORIDADEMANUT" => $row["NRPRIORIDADEMANUT"]
                    );
                    $impactosDesatualizados = $impactosRelacionados ? implode(',', $impactosRelacionados) : "-1";
                    $this->PrioridadeManutFactory->deleteImpactosDesatualizados($parametroImpactosDesatualizados, $impactosDesatualizados);
                }
            }

            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function insertImpactoRelacionado($NRPRIORIDADEMANUT, $NRIMPACTOMANUT, $nrorg, $operador)
    {
        $RELPRIORIDADEIMPACTO = $this->newCode->getCodeByTableName("FCM_RELPRIORIDADEIMPACTO", $nrorg, 1, 10, true);

        $parametrosImpactoRelacionado = array(
            "RELPRIORIDADEIMPACTO"  => $RELPRIORIDADEIMPACTO,
            "NRPRIORIDADEMANUT"     => $NRPRIORIDADEMANUT,
            "NRIMPACTOMANUT"        => $NRIMPACTOMANUT,
            "NRORG"                 => $nrorg,
            "CDOPERINCLUSAO"        => $operador,
            "NRORGINCLUSAO"         => $nrorg,
            "CDOPERULTATU"          => $operador,
            "NRORGULTATU"           => $nrorg
        );

        $this->PrioridadeManutFactory->insertImpactoRelacionado($parametrosImpactoRelacionado);
    }

    public function getPrioridadesManutencao()
    {
        $data = $this->PrioridadeManutFactory->getPrioridadesManutencao();
        return $data;
    }

    public function getImpactosRelacionados()
    {
        return $this->PrioridadeManutFactory->getImpactosRelacionados();
    }

    public function deletePrioridades($params)
    {
        $parametro = implode(',', $params["NRS"]);
        $this->PrioridadeManutFactory->deleteImpactosRelacionados($parametro);
        $this->PrioridadeManutFactory->deletePrioridades($parametro);
    }
}
