import { Utilities } from '@/util/Utilities';
import {
    DialogService, IGridEvent, LoadingService, Select, TextInput,
} from '@zeedhi/common';
import { Http, IEventParam, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class FmtParametrizacaoImpacto {
    public addNewRow({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRIMPACTOMANUT: newId }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NMIMPACTOMANUT_editable_${newId}`);
            nameInput.setFocus();
            this.fillSelects(component.datasource.data);
        }, 100);
    }

    public saveImpacto({ component, event }: IEventParam<TekGrid>) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            Http.post('saveImpacto', {
                ROWS: component.getEditedRows(),
            }).then(() => {
                Utilities.showSuccessMessage();
                component.datasource.get();
            }).catch((error: any) => {
                error.showErrorMessage();
            }).finally(() => {
                component.cancelEditedRows();
                LoadingService.hide();
            });
        }
    }

    public messageConfirmDelete({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'FmtParametrizacaoImpacto.deleteImpactos', 'Excluir Impactos');
    }

    public deleteImpactos() {
        const component = Metadata.getInstance<TekGrid>('tek-grid-impacto');

        LoadingService.show();
        Http.post('/deleteImpactos', {
            NRS: component.selectedRows.map((element: any) => element.NRIMPACTOMANUT),
        }).then(() => {
            Utilities.showSuccessMessage();
            component.datasource.get();
        }).catch((error: any) => {
            error.showErrorMessage();
        }).finally(() => {
            component.selectedRows = [];
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public setValue({ component }: IGridEvent) {
        const dados = component.datasource.data;
        setTimeout(() => {
            this.fillSelects(dados);
        }, 200);
    }

    public fillSelects(datasourceData: any) {
        datasourceData.forEach((value: { NRIMPACTOMANUT: any; NRPRIORIDADEMANUTPADR: any; }) => {
            if (value.NRIMPACTOMANUT !== 0) {
                const select = Metadata.getInstance<Select>(`NMPRIORIDADEMANUT_editable_${value.NRIMPACTOMANUT}`);
                select.setValue(value.NRPRIORIDADEMANUTPADR);
            }
        });
    }
}
