import { Utilities } from '@/util/Utilities';
import { DialogService, LoadingService, TextInput } from '@zeedhi/common';
import { Http, IEventParam, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class FmtParametrizacaoUnidadeMedida {
    public addNewRow({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRUNIDADEMEDIDA: newId }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NMUNIDADEMEDIDA_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public saveUnidadeMedida({ component, event }: IEventParam<TekGrid>) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            Http.post('saveUnidadeMedida', {
                ROWS: component.getEditedRows(),
            }).then(() => {
                Utilities.showSuccessMessage();
                component.datasource.get();
            }).catch((error: any) => {
                error.showErrorMessage();
            }).finally(() => {
                component.cancelEditedRows();
                LoadingService.hide();
            });
        }
    }

    public messageConfirmDelete({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'FmtParametrizacaoUnidadeMedida.deleteUnidadesMedida', 'Excluir Unidades de Medida');
    }

    public deleteUnidadesMedida() {
        const component = Metadata.getInstance<TekGrid>('tek-grid-unidade-medida');

        LoadingService.show();
        Http.post('/deleteUnidadesMedida', {
            NRS: component.selectedRows.map((element: any) => element.NRUNIDADEMEDIDA),
        }).then(() => {
            Utilities.showSuccessMessage();
            component.datasource.get();
        }).catch((error: any) => {
            error.showErrorMessage();
        }).finally(() => {
            component.selectedRows = [];
            LoadingService.hide();
            DialogService.hide();
        });
    }
}
